{
    "$graph": [
        {
            "class": "Workflow",
            "label": "CODEX analysis pipeline using Cytokit",
            "inputs": [
                {
                    "label": "Directory containing CODEX data",
                    "type": "Directory",
                    "id": "#main/data_dir"
                },
                {
                    "label": "GPUs to use, represented as a comma-separated list of integers.",
                    "type": "string",
                    "default": "0",
                    "id": "#main/gpus"
                }
            ],
            "steps": [
                {
                    "id": "#main/collect_dataset_info",
                    "in": [
                        {
                            "id": "#main/collect_dataset_info/base_directory",
                            "source": "#main/data_dir"
                        }
                    ],
                    "out": [
                        "#main/collect_dataset_info/pipeline_config"
                    ],
                    "run": "#collect_dataset_info.cwl",
                    "label": "Collect CODEX dataset info"
                },
                {
                    "id": "#main/create_yaml_config",
                    "in": [
                        {
                            "id": "#main/create_yaml_config/pipeline_config",
                            "source": "#main/collect_dataset_info/pipeline_config"
                        },
                        {
                            "id": "#main/create_yaml_config/gpus",
                            "source": "#main/gpus"
                        }
                    ],
                    "out": [
                        "#main/create_yaml_config/cytokit_config"
                    ],
                    "run": "#create_yaml_config.cwl",
                    "label": "Create Cytokit experiment config"
                },
                {
                    "id": "#main/cytokit_processor",
                    "in": [
                        {
                            "id": "#main/cytokit_processor/data_dir",
                            "source": "#main/data_dir"
                        },
                        {
                            "id": "#main/cytokit_processor/pipeline_config",
                            "source": "#main/collect_dataset_info/pipeline_config"
                        },
                        {
                            "id": "#main/cytokit_processor/yaml_config",
                            "source": "#main/create_yaml_config/cytokit_config"
                        }
                    ],
                    "out": [
                        "#main/cytokit_processor/cytokit_output"
                    ],
                    "run": "#cytokit_processor.cwl",
                    "label": "CODEX analysis via Cytokit 'processor'"
                },
                {
                    "id": "#main/cytokit_operator",
                    "in": [
                        {
                            "id": "#main/cytokit_operator/data_dir",
                            "source": "#main/cytokit_processor/cytokit_output"
                        },
                        {
                            "id": "#main/cytokit_operator/pipeline_config",
                            "source": "#main/collect_dataset_info/pipeline_config"
                        },
                        {
                            "id": "#main/cytokit_operator/yaml_config",
                            "source": "#main/create_yaml_config/cytokit_config"
                        }
                    ],
                    "out": [
                        "#main/cytokit_operator/cytokit_output"
                    ],
                    "run": "#cytokit_operator.cwl",
                    "label": "CODEX analysis via Cytokit 'operator'"
                },
                {
                    "id": "#main/ome_tiff_creation",
                    "in": [
                        {
                            "id": "#main/ome_tiff_creation/cytokit_processor_output",
                            "source": "#main/cytokit_processor/cytokit_output"
                        },
                        {
                            "id": "#main/ome_tiff_creation/cytokit_operator_output",
                            "source": "#main/cytokit_operator/cytokit_output"
                        },
                        {
                            "id": "#main/ome_tiff_creation/cytokit_config",
                            "source": "#main/create_yaml_config/cytokit_config"
                        }
                    ],
                    "out": [
                        "#main/ome_tiff_creation/ome_tiffs"
                    ],
                    "run": "#ome_tiff_creation.cwl",
                    "label": "Create OME-TIFF versions of Cytokit segmentation and extract results"
                },
                {
                    "id": "#main/run_sprm",
                    "in": [
                        {
                            "id": "#main/run_sprm/ometiff_dir",
                            "source": "#main/ome_tiff_creation/ome_tiffs"
                        }
                    ],
                    "out": [
                        "#main/run_sprm/sprm_output_dir"
                    ],
                    "run": "#run_sprm.cwl",
                    "label": "Run SPRM analysis of OME-TIFF files"
                },
                {
                    "id": "#main/create_dir_for_viz",
                    "in": [
                        {
                            "id": "#main/create_dir_for_viz/cytokit_config_file",
                            "source": "#main/create_yaml_config/cytokit_config"
                        },
                        {
                            "id": "#main/create_dir_for_viz/ometiff_dir",
                            "source": "#main/ome_tiff_creation/ome_tiffs"
                        },
                        {
                            "id": "#main/create_dir_for_viz/sprm_output",
                            "source": "#main/run_sprm/sprm_output_dir"
                        }
                    ],
                    "out": [
                        "#main/create_dir_for_viz/for_viz_dir"
                    ],
                    "run": "#create_dir_for_viz.cwl",
                    "label": "Create directory containing symlinks to relevant files for visualization team"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "outputSource": "#main/create_yaml_config/cytokit_config",
                    "type": "File",
                    "label": "Cytokit configuration format",
                    "id": "#main/experiment_config"
                },
                {
                    "outputSource": "#main/create_dir_for_viz/for_viz_dir",
                    "type": "File",
                    "label": "Archive of symbolic links to files for visualization team",
                    "id": "#main/for_viz_dir"
                },
                {
                    "outputSource": "#main/ome_tiff_creation/ome_tiffs",
                    "type": "Directory",
                    "label": "Segmentation masks in OME-TIFF format",
                    "id": "#main/ome_tiff_output"
                },
                {
                    "outputSource": "#main/run_sprm/sprm_output_dir",
                    "type": "Directory",
                    "label": "Directory containing all SPRM outputs",
                    "id": "#main/sprm_output_dir"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Collect dataset info for Cytokit",
            "hints": [
                {
                    "dockerPull": "hubmap/codex-scripts:1.6.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/collect_dataset_info.py",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#collect_dataset_info.cwl/base_directory"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pipelineConfig.json"
                    },
                    "id": "#collect_dataset_info.cwl/pipeline_config"
                }
            ],
            "id": "#collect_dataset_info.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Create directory containing symlinks to relevant files for visualization team",
            "hints": [
                {
                    "dockerPull": "hubmap/codex-scripts:1.6.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/create_visualization_dir.py",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#create_dir_for_viz.cwl/cytokit_config_file"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#create_dir_for_viz.cwl/ometiff_dir"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#create_dir_for_viz.cwl/sprm_output"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "symlinks.tar"
                    },
                    "id": "#create_dir_for_viz.cwl/for_viz_dir"
                }
            ],
            "id": "#create_dir_for_viz.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Create Cytokit experiment config",
            "hints": [
                {
                    "dockerPull": "hubmap/codex-scripts:1.6.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/create_cytokit_config.py",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--gpus=",
                        "separate": false
                    },
                    "id": "#create_yaml_config.cwl/gpus"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#create_yaml_config.cwl/pipeline_config"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "experiment.yaml"
                    },
                    "id": "#create_yaml_config.cwl/cytokit_config"
                }
            ],
            "id": "#create_yaml_config.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CODEX analysis via Cytokit",
            "hints": [
                {
                    "class": "https://raw.githubusercontent.com/hubmapconsortium/codex-pipeline/a04e55b/steps/DockerGpuRequirement"
                },
                {
                    "dockerPull": "hubmap/cytokit:1.6.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/cytokit_wrapper.py",
            "arguments": [
                "operator"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cytokit_operator.cwl/data_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cytokit_operator.cwl/pipeline_config"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#cytokit_operator.cwl/yaml_config"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "output"
                    },
                    "id": "#cytokit_operator.cwl/cytokit_output"
                }
            ],
            "id": "#cytokit_operator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CODEX analysis via Cytokit",
            "hints": [
                {
                    "class": "https://raw.githubusercontent.com/hubmapconsortium/codex-pipeline/a04e55b/steps/DockerGpuRequirement"
                },
                {
                    "dockerPull": "hubmap/cytokit:1.6.2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/cytokit_wrapper.py",
            "arguments": [
                "processor"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cytokit_processor.cwl/data_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cytokit_processor.cwl/pipeline_config"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#cytokit_processor.cwl/yaml_config"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "output"
                    },
                    "id": "#cytokit_processor.cwl/cytokit_output"
                }
            ],
            "id": "#cytokit_processor.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Create OME-TIFF versions of Cytokit segmentation and extract results",
            "hints": [
                {
                    "dockerPull": "hubmap/codex-scripts:1.6.2",
                    "class": "DockerRequirement"
                },
                {
                    "networkAccess": true,
                    "class": "NetworkAccess"
                }
            ],
            "baseCommand": "/opt/convert_to_ometiff.py",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#ome_tiff_creation.cwl/cytokit_config"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#ome_tiff_creation.cwl/cytokit_operator_output"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#ome_tiff_creation.cwl/cytokit_processor_output"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "output"
                    },
                    "id": "#ome_tiff_creation.cwl/ome_tiffs"
                }
            ],
            "id": "#ome_tiff_creation.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Run Spatial Process & Relationship Modeling (SPRM)",
            "hints": [
                {
                    "dockerPull": "hubmap/codex-scripts:1.6.2",
                    "class": "DockerRequirement"
                },
                {
                    "networkAccess": true,
                    "class": "NetworkAccess"
                }
            ],
            "baseCommand": "/opt/run_sprm.py",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#run_sprm.cwl/ometiff_dir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "sprm_outputs"
                    },
                    "id": "#run_sprm.cwl/sprm_output_dir"
                }
            ],
            "id": "#run_sprm.cwl"
        }
    ],
    "cwlVersion": "v1.1"
}
